@@ -303,6 +303,39 @@ public class AgentConfigManager implements Runnable {
     return communityMIB;
   }
 
+  /**
+   * Returns the NOTIFICATION-LOG-MIB implementation used by this config
+   * manager.
+   * @return
+   *    the NotificationLogMib instance of this agent.
+   * @since 1.4.2
+   */
+  public NotificationLogMib getNotificationLogMIB() {
+    return notificationLogMIB;
+  }
+
+  /**
+   * Returns the SNMP4J-LOG-MIB implementation used by this config
+   * manager.
+   * @return
+   *    the Snmp4jLogMib instance of this agent.
+   * @since 1.4.2
+   */
+  public Snmp4jLogMib getSnmp4jLogMIB() {
+    return snmp4jLogMIB;
+  }
+
+  /**
+   * Returns the SNMP4J-CONFIG-MIB implementation used by this config
+   * manager.
+   * @return
+   *    the Snmp4jConfigMib instance of this agent.
+   * @since 1.4.2
+   */
+  public Snmp4jConfigMib getsnmp4jConfigMIB() {
+    return snmp4jConfigMIB;
+  }
+
   /**
    * Launch the agent by registering and lauching (i.e., set to listen mode)
    * transport mappings.
